# Top 15 Twitter Ad Engagement Types used in YOUR case

## intro

Here we're going to find out how twitter used different ad enagagement types for making you interact with advertisements. Top 15 of them to plotted as horizontal bar chart.

## example

Here's a demo plot.

![twitterAdsCountGroupedByEngagementTypesForAnjan_Roy](../plots/twitterAdsCountGroupedByEngagementTypesForAnjan_Roy.png)
